# Automatically created by: scrapyd-deploy
from setuptools import setup, find_packages

setup(
    name             = 'json-pipeline',
    version          = '0.1.1',
    description      = 'Json processing pipeline tools',
    long_description = open('README.md').read(),
    license      = 'BSD',
    author       = 'Martin Olveyra',
    author_email = 'molveyra@gmail.com',
    url = 'https://github.com/kalessin/json-pipeline',
    packages         = find_packages(),
    classifiers = [
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
    ],
)



from importlib import import_module


# Copied from scrapy.utils.misc.load_object
def load_object(path):
    """Load an object given its absolute object path, and return it.
    object can be a class, function, variable or an instance.
    """

    try:
        dot = path.rindex('.')
    except ValueError:
        raise ValueError("Error loading object '%s': not a full path" % path)

    module, name = path[:dot], path[dot+1:]
    mod = import_module(module)

    try:
        obj = getattr(mod, name)
    except AttributeError:
        raise NameError("Module '%s' doesn't define any object named '%s'" % (module, name))

    return obj
